@@ -31,7 +31,7 @@ def error_exception(response: dict) -> Optional[BaseXToolsException]:
     :return: ``None`` or a ``BaseXToolsException`` (or subclass) instance.
     """
     if "error" not in response:
-        return
+        return None
 
     error = response["error"]
 
@@ -103,7 +103,7 @@ def build_path(path_format: str, params: Sequence[Tuple[str, Any, str]]) -> str:
     params_dict = {}
 
     def has_more(index):
-        for _, val, _ in params[index+1:]:
+        for _, val, _ in params[index + 1:]:
             if val:
                 return True
         return False
@@ -126,4 +126,4 @@ def build_path(path_format: str, params: Sequence[Tuple[str, Any, str]]) -> str:
         params_dict[name] = urlquote(param_value)
 
     path = path_format.format(**params_dict).rstrip("/")
-    return path
\ No newline at end of file
+    return path
